% -------------------------------------------------------------------------
% Program: simple CRS input-oriented DEA problem for one DMU
% Author:  Eugene P. Morgunov 
% Date:    May 21, 2005
% -------------------------------------------------------------------------

% This example of solving DEA problem is taken from the file deap.pdf (p. 15)

% conditions -- CRS input-oriented problem, 5 DMUs, 2 inputs, 1 output
fprintf( 'Problem -- CRS input-oriented, 5 DMUs, 2 inputs, 1 output\n\n' );

% we have 6 variables -- 1 variable is theta
%                        5 variables are lambda's
% we name all them as x's (for simplicity) --
% so x( 1 ) == theta
%    x( 2 ) == lambda1
%    x( 3 ) == lambda2, etc.

% we must prepare parameters for linprog() function

% objective function
f = [ 1; 0; 0; 0; 0; 0 ];

% matrix of constraints is formed for DMU 3 (as in example in deap.pdf file)

% we should keep in mind that linprog() function demands that signs of
% constraints be '<=' (and not '>=') so we can multiply constraints, 
% that are in the form of inequalities, by -1. That's why values for outputs
% gain minus sign;
% the first column in this matrix represents values for DMU that is being
% optimized (DMU 3 in this case)
A = [  0 -1 -2 -3 -1 -2;
      -6  2  2  6  3  6;
      -6  5  4  6  2  2
    ];
    
% column of RHSs
% minus sign by value of y appears because of multiplying constraint
% by -1
b = [ -3; 0; 0 ];

% lower bounds on decision variables are zeros
lb = zeros( 6, 1 );

% call to linprog function for solving linear problem
% we don't have constraints in the form of equalities so pass empty matrices
x = linprog( f, A, b, [], [], lb);

% display results
fprintf( 'Results of computations\n\n' );
disp( x );

% the value of efficiency measure that DMU 3 has
fprintf( 'Efficiency measure (Value of theta) = %f\n\n', x( 1, 1 ) );

fprintf( 'Reference DMUs and their weights\n\n' );

% reference DMUs and their weights
for i = 2 : 6   % lambda's have numbers from 2 to 6
  if ( x( i ) > 0.000001 )  % we use 0.000001 instead of zero
    % (i - 1) -- because the first lambda has number 2, etc.
    fprintf( 'DMU %d   Weight = %5.4f\n', i - 1, x( i ) );
  end
end
