% ---------------------------------------------------------------------------
% Program: sample of user function for reading data from a text file
% Author:  Eugene P. Morgunov 
% Date:    May 22, 2005
% ---------------------------------------------------------------------------
function [ X, Y ] = get_data( data_file, DMUs_num, inputs_num, outputs_num )

% Function for getting data from a text file 
% Parameters
%         data_file - the name of a text file containing data for all DMUs;
%         DMUs_num - number of DMUs;
%         inputs_num - number of inputs;
%         outputs_num - number of outputs.
% Return value - vector of two elements:
%         X - matrix of inputs;
%         Y - matrix of outputs

% NOTE. Columns for outputs in a data file come first, columns for inputs -
%       after them (this order is taken from DEAP program by T. Coelli).

% open the text file
% fid is a scalar MATLAB integer, called a file identifier
fid = fopen( data_file, 'r' );

if ( fid == -1 )
  fprintf( 'Can not open file %s', data_file );
  X = [];
  Y = [];
  return;
end

format_string = '';

% create format string
for i = 1 : inputs_num + outputs_num
  format_string = [ format_string ' %f' ];
end

DATA = fscanf( fid, format_string, [ inputs_num + outputs_num, DMUs_num ] );

fclose( fid );

Y = DATA( 1 : outputs_num, : );
X = DATA( outputs_num + 1 : outputs_num + inputs_num, : );
